﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using Google.GData.Client;
using Google.GData.Photos;
using System.Data;
using Google.GData.Extensions.MediaRss;
using System.IO;
using System.Drawing;

namespace Picasa
{
    public partial class _Default : System.Web.UI.Page
    {
        #region Properties
        public string Username
        {
            get
            {
                return ViewState["Username"] != null ? Convert.ToString(ViewState["Username"]) : String.Empty;
            }
            set
            {
                ViewState["Username"] = value;
            }
        }
        
        public string Password
        {
            get
            {
                return ViewState["Password"] != null ? Convert.ToString(ViewState["Password"]) : String.Empty;
            }
            set
            {
                ViewState["Password"] = value;
            }
        }

        public string AuthToken
        {
            get
            {
                return ViewState["AuthToken"] != null ? Convert.ToString(ViewState["AuthToken"]) : String.Empty;
            }
            set
            {
                ViewState["AuthToken"] = value;
            }
        }

        public string SelectedAlbumID
        {
            get
            {
                return ViewState["SelectedAlbumID"] != null ? Convert.ToString(ViewState["SelectedAlbumID"]) : String.Empty;
            }
            set
            {
                ViewState["SelectedAlbumID"] = value;
            }
        }

        private PicasaService picasaService = new PicasaService("Picasa");
        #endregion

        #region Page Events
        protected override void OnInit(EventArgs e)
        {
            base.OnInit(e);
            phPicasaAlbums.Visible = false;
            dlAlbums.ItemCommand += new DataListCommandEventHandler(dlAlbums_ItemCommand);
            btnConnect.Click += new EventHandler(btnConnect_Click);
            dlAlbums.SelectedIndexChanged += new EventHandler(dlAlbums_SelectedIndexChanged);
        }
     
        protected void Page_Load(object sender, EventArgs e)
        {
            
        }

        #endregion

        #region Methods
        private void BindAlbums()
        {
            try
            {

                AlbumQuery query = new AlbumQuery();

                query.Uri = new Uri(PicasaQuery.CreatePicasaUri(this.Username));

                picasaService.setUserCredentials(this.Username, this.Password);
                AuthToken = picasaService.QueryClientLoginToken();
                PicasaFeed picasaFeed = picasaService.Query(query);

                if (picasaFeed != null)
                {
                    dlAlbums.DataSource = picasaFeed.Entries;
                    dlAlbums.DataBind();
                }

                phPicasaAlbums.Visible = true;
                phGoogleConect.Visible = false;
            }
            catch (Exception ex)
            {
                cvCredentials.ErrorMessage = ex.Message;
                cvCredentials.IsValid = false;
            }
        }
        #endregion

        #region UI Events
        void dlAlbums_SelectedIndexChanged(object sender, EventArgs e)
        {
            
        }

        void dlAlbums_ItemCommand(object source, DataListCommandEventArgs e)
        {
            if (!String.IsNullOrEmpty(AuthToken))
            {
                PhotoQuery query = new PhotoQuery();
                SelectedAlbumID = e.CommandArgument.ToString();
                query.Uri = new Uri(PicasaQuery.CreatePicasaUri(this.Username, SelectedAlbumID));
                
                picasaService.SetAuthenticationToken(AuthToken);

                PicasaFeed picasaFeed = picasaService.Query(query);

                if (picasaFeed != null && picasaFeed.Entries.Count > 0)
                {
                    dlPhotos.DataSource = picasaFeed.Entries;
                }
                dlPhotos.DataBind();

                phPicasaAlbums.Visible = true;
                phGoogleConect.Visible = false;
            }
        }

        void btnConnect_Click(object sender, EventArgs e)
        {
                this.Password = txtPassword.Text;
                this.Username = txtUsername.Text;

                BindAlbums();
        } 
        #endregion
        
    }
}
